#  tests for pot-0.8.0-py310hf5e1058_0 (this is a generated file);
print('===== testing package: pot-0.8.0-py310hf5e1058_0 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import numpy as np
import ot

n = 5
a, b = np.random.dirichlet([1] * n, size=2)
M = ot.dist(np.random.randn(n, 5))

W = ot.emd2(a, b, M)
W_reg = ot.sinkhorn2(a, b, M, .1)

T = ot.emd(a, b, M)
T_reg = ot.sinkhorn(a, b, M, .1)
#  --- run_test.py (end) ---

print('===== pot-0.8.0-py310hf5e1058_0 OK =====');
print("import: 'ot'")
import ot

